import type { ContentQuality } from '../types/index.js';
/**
 * 内容分析器
 * 提供深度的内容质量分析、分类和评估功能
 */
export declare class ContentAnalyzer {
    /**
     * 深度内容质量分析
     */
    analyzeContentQuality(content: any, type: 'article' | 'pin'): ContentQuality;
    /**
     * 分析文章质量
     */
    private analyzeArticleQuality;
    /**
     * 分析沸点质量
     */
    private analyzePinQuality;
    /**
     * 分析内容结构
     */
    private analyzeContentStructure;
    /**
     * 分析参与质量
     */
    private analyzeEngagementQuality;
    /**
     * 分析作者可信度
     */
    private analyzeAuthorCredibility;
    /**
     * 分析技术深度
     */
    private analyzeTechnicalDepth;
    /**
     * 分析可读性
     */
    private analyzeReadability;
    /**
     * 分析原创性
     */
    private analyzeOriginality;
    /**
     * 分析时效性
     */
    private analyzeTimeliness;
    /**
     * 分析视觉吸引力
     */
    private analyzeVisualAppeal;
    /**
     * 计算综合质量分数
     */
    private calculateOverallQuality;
    /**
     * 预测内容表现
     */
    private predictContentPerformance;
    /**
     * 沸点相关分析方法
     */
    private analyzePinRelevance;
    private analyzePinEngagementPotential;
    private analyzeAuthorInfluence;
    private analyzePinCreativity;
    private analyzeDiscussionValue;
    private analyzeViralPotential;
    private calculatePinQuality;
    private predictPinPerformance;
    /**
     * 批量内容质量分析
     */
    batchAnalyzeQuality(contents: any[], type: 'article' | 'pin'): Promise<ContentQuality[]>;
    /**
     * 内容分类
     */
    classifyContent(content: any, type: 'article' | 'pin'): string;
    private classifyArticle;
    private classifyPin;
}
export declare const contentAnalyzer: ContentAnalyzer;
