import type { UserInfo } from '../types/index.js';
/**
 * 用户相关API
 */
export declare class UserApi {
    /**
     * 获取用户信息
     */
    getUserInfo(userId: string): Promise<UserInfo>;
    /**
     * 批量获取用户信息
     */
    getBatchUserInfo(userIds: string[]): Promise<{
        users: UserInfo[];
        errors: {
            userId: string;
            error: string;
        }[];
    }>;
    /**
     * 获取推荐作者列表
     */
    getRecommendedAuthors(limit?: number): Promise<{
        score: number;
        user: UserInfo;
        article_count: number;
        total_diggs: number;
        total_views: number;
    }[]>;
    /**
     * 搜索用户
     */
    searchUsers(keyword: string, limit?: number): Promise<{
        users: UserInfo[];
        count: number;
        keyword: string;
    }>;
    /**
     * 获取用户统计信息
     */
    getUserStats(userId: string): Promise<{
        user_id: string;
        user_name: string;
        basic_stats: {
            level: number;
            power: number;
            followee_count: number;
            follower_count: number;
            post_article_count: number;
            post_shortmsg_count: number;
            got_digg_count: number;
            got_view_count: number;
        };
        engagement_rate: number;
        influence_score: number;
        activity_level: "low" | "medium" | "high" | "unknown";
    }>;
    /**
     * 获取用户排行榜
     */
    getUserRanking(type?: 'followers' | 'articles' | 'diggs' | 'views', limit?: number): Promise<{
        ranking: {
            rank: number;
            user: UserInfo;
            value: number;
        }[];
        type: "articles" | "followers" | "diggs" | "views";
        total_users: number;
    }>;
    /**
     * 获取排行榜对应的数值
     */
    private getRankingValue;
    /**
     * 分析用户兴趣标签
     */
    analyzeUserInterests(userId: string): Promise<{
        user_id: string;
        interests: never[];
        categories: never[];
        total_articles?: never;
    } | {
        user_id: string;
        total_articles: number;
        interests: {
            tag: string;
            count: number;
            weight: number;
        }[];
        categories: {
            category: string;
            count: number;
            weight: number;
        }[];
    }>;
}
export declare const userApi: UserApi;
